[![Build Status](https://secure.travis-ci.org/haiwen/python-seafile.svg?branch=master)](http://travis-ci.org/haiwen/python-seafile)

python-seafile-2022
==============

python client for seafile web api

Doc: https://github.com/haiwen/python-seafile/blob/master/doc.md
